@@ -91,19 +91,7 @@ def reddit_frequency(frequency: Frequency) -> str:
         Frequency.Yearly: "year",
     }
 
-    return mapper.get(frequency, "month")
-
-
-def sanitize_url(args, path: str) -> str:
-    matches = REGEX_SUBREDDIT.match(path)
-    if matches:
-        subreddit = matches.groups()[0]
-        return "https://old.reddit.com/r/" + subreddit + "/top/?sort=top&t=" + reddit_frequency(args.frequency)
-
-    if "/m." in path:
-        return path.replace("/m.", "/www.")
-
-    return path
+    return mapper[frequency]
 
 
 def get_text_files(path: Path, OCR=False, speech_recognition=False) -> List[str]:
